
#line 3 "lex.yy.c"

#include "univ.i"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 109
#define YY_END_OF_BUFFER 110
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[370] =
    {   0,
        0,    0,  104,  104,    0,    0,  110,  108,  107,  107,
       99,    3,   88,   94,   97,   95,   92,   96,  108,   98,
        1,  108,   93,   91,   89,   90,  102,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   82,   82,   82,
       82,   82,   82,   82,   82,  100,  101,  104,  105,    4,
        5,  107,   83,  103,    2,    1,   84,   85,   87,   86,
       82,   82,   82,   82,   82,   82,   40,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   82,   82,   82,
       82,   23,   12,   20,   82,   82,   82,   82,   50,   57,
       82,    9,   82,   82,   82,   82,   82,   82,   82,   82,

       82,   82,   82,   82,   82,   82,   82,   82,   82,  104,
      105,  105,  106,    4,    5,    2,    8,   41,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   22,   82,   82,   36,
       82,   82,   82,   16,   82,   82,   10,   82,   82,   82,
       13,   82,   82,   82,   82,   82,   76,   82,   82,   82,
       47,    7,   82,   31,   82,   82,   82,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   15,   19,   82,
       82,   82,   82,   82,   82,   82,   82,   82,   82,   82,
       42,   82,   82,   25,   82,   82,   82,   34,   82,   82,

       82,   82,   44,   82,   27,   82,    6,   60,   82,   82,
       82,   38,   82,   82,   82,   82,   82,   82,   82,   82,
       82,   24,   82,   82,   82,   82,   82,   82,   82,   82,
       81,   82,   21,   82,   62,   82,   82,   82,   82,   32,
       82,   82,   82,   82,   82,   82,   82,   26,   61,   18,
       53,   82,   71,   82,   82,   82,   39,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   52,   82,   82,
       82,   82,   82,   82,   35,   28,   75,   14,   82,   79,
       70,   82,   51,   82,   59,   82,   48,   82,   82,   43,
       82,   72,   82,   74,   82,   82,   29,   82,   82,   82,

       30,   68,   82,   82,   82,   82,   54,   46,   45,   82,
       82,   82,   49,   58,   82,   82,   17,   82,   82,   69,
       77,   82,   82,   73,   82,   64,   82,   82,   82,   82,
       33,   82,   63,   82,   80,   82,   82,   82,   82,   55,
       82,   82,   11,   82,   66,   65,   82,   37,   82,   78,
       82,   82,   82,   82,   82,   82,   82,   82,   82,   82,
       67,   82,   82,   82,   82,   82,   82,   56,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    4,    1,    5,    6,
        7,    8,    9,   10,   11,   12,   13,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   15,   16,   17,
       18,   19,   20,    1,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
       37,   38,   39,   40,   41,   42,   43,   44,   45,   30,
        1,    1,    1,    1,   46,    1,   30,   30,   30,   30,

       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   47,    1,   48,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[49] =
    {   0,
        1,    1,    1,    1,    2,    1,    1,    3,    1,    1,
        1,    1,    1,    4,    1,    1,    1,    1,    1,    1,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    1,    1
    } ;

static yyconst flex_int16_t yy_base[376] =
    {   0,
        0,    0,  390,  389,  391,  390,  394,  399,   47,   49,
      399,  399,  399,  399,  399,  399,  399,  399,  381,  384,
       41,  373,  399,   38,  399,  372,  399,   20,   33,   32,
       46,   29,   44,    0,   46,   49,   42,   60,  351,   65,
       66,   67,   32,  367,   69,  399,  399,    0,   79,    0,
      382,  103,  399,  399,  372,   96,  399,  399,  399,  399,
        0,  361,   70,  357,  349,  347,    0,  360,   77,   80,
      355,  341,   92,  339,  352,  337,  351,  334,  338,  334,
      336,    0,   93,    0,  336,  334,  328,  335,    0,    0,
      341,  341,  324,   87,   98,  339,   93,   88,  330,  104,

      322,  338,  334,  312,  328,  332,  323,   98,  316,    0,
      122,  131,  399,    0,  348,  338,    0,    0,  326,  321,
      328,  326,  309,  307,  306,  311,  106,  309,  321,  102,
      309,  315,  316,  298,  298,  117,    0,  313,  314,    0,
      301,  308,  118,  122,  305,  295,  304,  297,  294,  302,
        0,  292,  302,  300,  291,  281,  275,  288,  273,  293,
        0,    0,  278,    0,  292,  283,  280,  126,  276,  291,
      270,  272,  277,  277,  269,  272,  267,    0,    0,  279,
      263,  273,  280,  271,  259,  258,  272,  261,  274,  254,
        0,  264,  246,    0,  265,  262,  249,    0,  244,  249,

      248,  258,    0,  244,    0,  248,    0,    0,  244,  241,
      255,    0,  240,  240,  238,  254,  239,  251,  233,  251,
      246,    0,  241,  241,  227,  226,  226,  240,  239,  238,
        0,  222,    0,  216,    0,  235,  219,  218,  218,    0,
      231,  221,  216,  215,  227,  217,  216,    0,    0,    0,
        0,  209,    0,  223,  219,  205,    0,  219,  220,  203,
      208,  201,  219,  201,  198,  199,  196,    0,  201,  213,
      200,  207,  206,  191,    0,    0,    0,  183,  190,    0,
        0,  187,    0,  186,    0,  200,    0,  201,  188,    0,
      184,    0,  187,    0,  179,  181,    0,  180,  194,  187,

        0,    0,  190,  193,  175,  190,    0,    0,    0,  171,
      185,  184,    0,    0,  168,  167,    0,  182,  167,    0,
        0,  173,  169,    0,  164,    0,  176,  165,  175,  164,
        0,  151,    0,  171,    0,  155,  149,  155,  146,    0,
      151,  164,    0,  163,    0,    0,  154,    0,  158,    0,
      145,  145,  151,  137,  160,  152,  153,  137,  121,  110,
        0,  122,  129,  120,  117,  113,  105,    0,  399,  160,
      164,   85,  168,  172,  176
    } ;

static yyconst flex_int16_t yy_def[376] =
    {   0,
      369,    1,  370,  370,  371,  371,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  369,  369,  373,  374,  375,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,

      372,  372,  372,  372,  372,  372,  372,  372,  372,  373,
      374,  374,  369,  375,  369,  369,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,

      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,

      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  372,  372,    0,  369,
      369,  369,  369,  369,  369
    } ;

static yyconst flex_int16_t yy_nxt[448] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   34,   34,   35,   34,
       34,   36,   34,   37,   38,   39,   34,   40,   41,   42,
       43,   44,   45,   34,   34,   34,   46,   47,   52,   52,
       52,   52,   55,   62,   56,   58,   59,   64,   63,   68,
       76,   65,   77,   69,   66,  105,   70,  106,   78,   71,
       73,   82,   72,   85,   74,   79,   87,   67,   80,   83,
       75,   81,   88,   86,   84,   89,  112,  102,   61,   95,
       98,  113,  118,   90,  103,   91,  108,   92,   96,   97,

       93,  104,   99,  109,   52,   52,  100,   55,  119,   56,
      101,  124,  126,  127,  131,  152,  142,  125,  154,  160,
      128,  153,  172,  132,  158,  163,  173,  161,  183,  369,
      133,  143,  144,  155,  369,  159,  164,  156,  112,  187,
      188,  194,  200,  113,  184,  195,  202,  223,  224,  368,
      367,  366,  365,  364,  363,  362,  203,  201,  361,  225,
       48,   48,   48,   48,   50,   50,   50,   50,  110,  110,
      360,  110,  111,  111,  111,  111,  114,  359,  114,  114,
      358,  357,  356,  355,  354,  353,  352,  351,  350,  349,
      348,  347,  346,  345,  344,  343,  342,  341,  340,  339,

      338,  337,  336,  335,  334,  333,  332,  331,  330,  329,
      328,  327,  326,  325,  324,  323,  322,  321,  320,  319,
      318,  317,  316,  315,  314,  313,  312,  311,  310,  309,
      308,  307,  306,  305,  304,  303,  302,  301,  300,  299,
      298,  297,  296,  295,  294,  293,  292,  291,  290,  289,
      288,  287,  286,  285,  284,  283,  282,  281,  280,  279,
      278,  277,  276,  275,  274,  273,  272,  271,  270,  269,
      268,  267,  266,  265,  264,  263,  262,  261,  260,  259,
      258,  257,  256,  255,  254,  253,  252,  251,  250,  249,
      248,  247,  246,  245,  244,  243,  242,  241,  240,  239,

      238,  237,  236,  235,  234,  233,  232,  231,  230,  229,
      228,  227,  226,  222,  221,  220,  219,  218,  217,  216,
      215,  214,  213,  212,  211,  210,  209,  208,  207,  206,
      205,  204,  199,  198,  197,  196,  193,  192,  191,  190,
      189,  186,  185,  182,  181,  180,  179,  178,  177,  176,
      175,  116,  115,  174,  171,  170,  169,  168,  167,  166,
      165,  162,  157,  151,  150,  149,  148,  147,  146,  145,
      141,  140,  139,  138,  137,  136,  135,  134,  130,  129,
      123,  122,  121,  120,  117,  116,  115,  107,   94,   60,
       57,   54,   53,  369,   51,   51,   49,   49,    7,  369,

      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369
    } ;

static yyconst flex_int16_t yy_chk[448] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    9,    9,
       10,   10,   21,   28,   21,   24,   24,   29,   28,   30,
       32,   29,   32,   30,   29,   43,   30,   43,   33,   30,
       31,   35,   30,   36,   31,   33,   37,   29,   33,   35,
       31,   33,   37,   36,   35,   38,   49,   42,  372,   40,
       41,   49,   63,   38,   42,   38,   45,   38,   40,   40,

       38,   42,   41,   45,   52,   52,   41,   56,   63,   56,
       41,   69,   70,   70,   73,   94,   83,   69,   95,   98,
       70,   94,  108,   73,   97,  100,  108,   98,  127,  111,
       73,   83,   83,   95,  111,   97,  100,   95,  112,  130,
      130,  136,  143,  112,  127,  136,  144,  168,  168,  367,
      366,  365,  364,  363,  362,  360,  144,  143,  359,  168,
      370,  370,  370,  370,  371,  371,  371,  371,  373,  373,
      358,  373,  374,  374,  374,  374,  375,  357,  375,  375,
      356,  355,  354,  353,  352,  351,  349,  347,  344,  342,
      341,  339,  338,  337,  336,  334,  332,  330,  329,  328,

      327,  325,  323,  322,  319,  318,  316,  315,  312,  311,
      310,  306,  305,  304,  303,  300,  299,  298,  296,  295,
      293,  291,  289,  288,  286,  284,  282,  279,  278,  274,
      273,  272,  271,  270,  269,  267,  266,  265,  264,  263,
      262,  261,  260,  259,  258,  256,  255,  254,  252,  247,
      246,  245,  244,  243,  242,  241,  239,  238,  237,  236,
      234,  232,  230,  229,  228,  227,  226,  225,  224,  223,
      221,  220,  219,  218,  217,  216,  215,  214,  213,  211,
      210,  209,  206,  204,  202,  201,  200,  199,  197,  196,
      195,  193,  192,  190,  189,  188,  187,  186,  185,  184,

      183,  182,  181,  180,  177,  176,  175,  174,  173,  172,
      171,  170,  169,  167,  166,  165,  163,  160,  159,  158,
      157,  156,  155,  154,  153,  152,  150,  149,  148,  147,
      146,  145,  142,  141,  139,  138,  135,  134,  133,  132,
      131,  129,  128,  126,  125,  124,  123,  122,  121,  120,
      119,  116,  115,  109,  107,  106,  105,  104,  103,  102,
      101,   99,   96,   93,   92,   91,   88,   87,   86,   85,
       81,   80,   79,   78,   77,   76,   75,   74,   72,   71,
       68,   66,   65,   64,   62,   55,   51,   44,   39,   26,
       22,   20,   19,    7,    6,    5,    4,    3,  369,  369,

      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "pars0lex.l"
/******************************************************
SQL parser lexical analyzer: input file for the GNU Flex lexer generator

(c) 1997 Innobase Oy

Created 12/14/1997 Heikki Tuuri
Published under the GPL version 2

The InnoDB parser is frozen because MySQL takes care of SQL parsing.
Therefore we normally keep the InnoDB parser C files as they are, and do
not automatically generate them from pars0grm.y and pars0lex.l.

How to make the InnoDB parser and lexer C files:

1. First do
        bison -d pars0grm.y
   That generates pars0grm.tab.c and pars0grm.tab.h.

2. Rename pars0grm.tab.c to pars0grm.c and pars0grm.tab.h to pars0grm.h.

3. Copy pars0grm.h also to /innobase/include

4. Do
        flex pars0lex.l
   That generates lex.yy.c.

5. Rename lex.yy.c to lexyy.c.

6. Remove the #include of unistd.h from about line 2500 of lexyy.c

7. Add '#include "univ.i"' before #include <stdio.h> in lexyy.c
   (Needed for AIX)

8. Add a type cast to int to the assignment below the comment
   'need more input.'  (Removes a warning on Win64)

These instructions seem to work at least with bison-1.28 and flex-2.5.4 on
Linux.
*******************************************************/
#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1
#line 56 "pars0lex.l"
#define YYSTYPE que_node_t*

#include "univ.i"
#include "pars0pars.h"
#include "pars0grm.h"
#include "pars0sym.h"
#include "mem0mem.h"
#include "os0proc.h"

#define malloc(A)	ut_malloc(A)
#define free(A)		ut_free(A)
#define realloc(P, A)	ut_realloc(P, A)
#define exit(A) 	ut_error

#define YY_INPUT(buf, result, max_size) pars_get_lex_chars(buf, &result, max_size)

/* String buffer for removing quotes */
static ulint	stringbuf_len_alloc = 0; /* Allocated length */
static ulint	stringbuf_len = 0; /* Current length */
static char*	stringbuf; /* Start of buffer */
/* Appends a string to the buffer. */
static
void
string_append(
/*==========*/
	const char*	str,	/* in: string to be appended */
	ulint		len)	/* in: length of the string */
{
	if (stringbuf == NULL) {
		stringbuf = malloc(1);
		stringbuf_len_alloc = 1;
	}

	if (stringbuf_len + len > stringbuf_len_alloc) {
		while (stringbuf_len + len > stringbuf_len_alloc) {
			stringbuf_len_alloc <<= 1;
		}
		stringbuf = realloc(stringbuf, stringbuf_len_alloc);
	}

	memcpy(stringbuf + stringbuf_len, str, len);
	stringbuf_len += len;
}



#line 751 "lex.yy.c"

#define INITIAL 0
#define comment 1
#define quoted 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 106 "pars0lex.l"


#line 905 "lex.yy.c"

	if ( (yy_init) )
		{
		(yy_init) = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 370 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 369 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 108 "pars0lex.l"
{
			yylval = sym_tab_add_int_lit(pars_sym_tab_global,
								atoi(yytext));
			return(PARS_INT_LIT);
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 114 "pars0lex.l"
{
			ut_error;	/* not implemented */

			return(PARS_FLOAT_LIT);
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 120 "pars0lex.l"
{
/* Quoted character string literals are handled in an explicit
start state 'quoted'.  This state is entered and the buffer for
the scanned string is emptied upon encountering a starting quote.

In the state 'quoted', only two actions are possible (defined below). */
			BEGIN(quoted);
			stringbuf_len = 0;
}
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 129 "pars0lex.l"
{
			/* Got a sequence of characters other than "'":
			append to string buffer */
			string_append(yytext, yyleng);
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 134 "pars0lex.l"
{
			/* Got a sequence of "'" characters:
			append half of them to string buffer,
			as "''" represents a single "'".
			We apply truncating division,
			so that "'''" will result in "'". */

			string_append(yytext, yyleng / 2);

			/* If we got an odd number of quotes, then the
			last quote we got is the terminating quote.
			At the end of the string, we return to the
			initial start state and report the scanned
			string literal. */

			if (yyleng % 2) {
				BEGIN(INITIAL);
				yylval = sym_tab_add_str_lit(
					pars_sym_tab_global,
					(byte*) stringbuf, stringbuf_len);
				return(PARS_STR_LIT);
			}
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 158 "pars0lex.l"
{
			yylval = sym_tab_add_null_lit(pars_sym_tab_global);

			return(PARS_NULL_LIT);
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 164 "pars0lex.l"
{
			/* Implicit cursor name */
			yylval = sym_tab_add_str_lit(pars_sym_tab_global,
							(byte*) yytext, yyleng);
			return(PARS_SQL_TOKEN);
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 171 "pars0lex.l"
{
			return(PARS_AND_TOKEN);
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 175 "pars0lex.l"
{
			return(PARS_OR_TOKEN);
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 179 "pars0lex.l"
{
			return(PARS_NOT_TOKEN);
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 183 "pars0lex.l"
{
			return(PARS_PROCEDURE_TOKEN);
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 187 "pars0lex.l"
{
			return(PARS_IN_TOKEN);
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 191 "pars0lex.l"
{
			return(PARS_OUT_TOKEN);
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 195 "pars0lex.l"
{
	 		return(PARS_BINARY_TOKEN);
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 199 "pars0lex.l"
{
	 		return(PARS_BLOB_TOKEN);
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 203 "pars0lex.l"
{
	 		return(PARS_INT_TOKEN);
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 207 "pars0lex.l"
{
	 		return(PARS_INT_TOKEN);
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 211 "pars0lex.l"
{
	 		return(PARS_FLOAT_TOKEN);
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 215 "pars0lex.l"
{
	 		return(PARS_CHAR_TOKEN);
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 219 "pars0lex.l"
{
			return(PARS_IS_TOKEN);
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 223 "pars0lex.l"
{
			return(PARS_BEGIN_TOKEN);
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 227 "pars0lex.l"
{
			return(PARS_END_TOKEN);
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 231 "pars0lex.l"
{
			return(PARS_IF_TOKEN);
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 235 "pars0lex.l"
{
			return(PARS_THEN_TOKEN);
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 239 "pars0lex.l"
{
			return(PARS_ELSE_TOKEN);
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 243 "pars0lex.l"
{
			return(PARS_ELSIF_TOKEN);
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 247 "pars0lex.l"
{
			return(PARS_LOOP_TOKEN);
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 251 "pars0lex.l"
{
			return(PARS_WHILE_TOKEN);
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 255 "pars0lex.l"
{
			return(PARS_RETURN_TOKEN);
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 259 "pars0lex.l"
{
			return(PARS_SELECT_TOKEN);
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 263 "pars0lex.l"
{
			return(PARS_SUM_TOKEN);
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 267 "pars0lex.l"
{
			return(PARS_COUNT_TOKEN);
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 271 "pars0lex.l"
{
			return(PARS_DISTINCT_TOKEN);
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 275 "pars0lex.l"
{
			return(PARS_FROM_TOKEN);
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 279 "pars0lex.l"
{
			return(PARS_WHERE_TOKEN);
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 283 "pars0lex.l"
{
			return(PARS_FOR_TOKEN);
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 287 "pars0lex.l"
{
			return(PARS_CONSISTENT_TOKEN);
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 291 "pars0lex.l"
{
			return(PARS_READ_TOKEN);
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 295 "pars0lex.l"
{
			return(PARS_ORDER_TOKEN);
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 299 "pars0lex.l"
{
			return(PARS_BY_TOKEN);
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 303 "pars0lex.l"
{
			return(PARS_ASC_TOKEN);
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 307 "pars0lex.l"
{
			return(PARS_DESC_TOKEN);
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 311 "pars0lex.l"
{
			return(PARS_INSERT_TOKEN);
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 315 "pars0lex.l"
{
			return(PARS_INTO_TOKEN);
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 319 "pars0lex.l"
{
			return(PARS_VALUES_TOKEN);
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 323 "pars0lex.l"
{
			return(PARS_UPDATE_TOKEN);
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 327 "pars0lex.l"
{
			return(PARS_SET_TOKEN);
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 331 "pars0lex.l"
{
			return(PARS_DELETE_TOKEN);
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 335 "pars0lex.l"
{
			return(PARS_CURRENT_TOKEN);
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 339 "pars0lex.l"
{
			return(PARS_OF_TOKEN);
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 343 "pars0lex.l"
{
			return(PARS_CREATE_TOKEN);
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 347 "pars0lex.l"
{
			return(PARS_TABLE_TOKEN);
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 351 "pars0lex.l"
{
	 		return(PARS_INDEX_TOKEN);
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 355 "pars0lex.l"
{
	 		return(PARS_UNIQUE_TOKEN);
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 359 "pars0lex.l"
{
	 		return(PARS_CLUSTERED_TOKEN);
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 363 "pars0lex.l"
{
			return(PARS_DOES_NOT_FIT_IN_MEM_TOKEN);
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 367 "pars0lex.l"
{
	 		return(PARS_ON_TOKEN);
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 371 "pars0lex.l"
{
			return(PARS_DECLARE_TOKEN);
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 375 "pars0lex.l"
{
			return(PARS_CURSOR_TOKEN);
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 379 "pars0lex.l"
{
			return(PARS_OPEN_TOKEN);
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 383 "pars0lex.l"
{
			return(PARS_FETCH_TOKEN);
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 387 "pars0lex.l"
{
			return(PARS_CLOSE_TOKEN);
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 391 "pars0lex.l"
{
			return(PARS_NOTFOUND_TOKEN);
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 395 "pars0lex.l"
{
			return(PARS_TO_CHAR_TOKEN);
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 399 "pars0lex.l"
{
			return(PARS_TO_NUMBER_TOKEN);
}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 403 "pars0lex.l"
{
			return(PARS_TO_BINARY_TOKEN);
}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 407 "pars0lex.l"
{
			return(PARS_BINARY_TO_NUMBER_TOKEN);
}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 411 "pars0lex.l"
{
			return(PARS_SUBSTR_TOKEN);
}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 415 "pars0lex.l"
{
			return(PARS_REPLSTR_TOKEN);
}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 419 "pars0lex.l"
{
			return(PARS_CONCAT_TOKEN);
}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 423 "pars0lex.l"
{
			return(PARS_INSTR_TOKEN);
}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 427 "pars0lex.l"
{
			return(PARS_LENGTH_TOKEN);
}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 431 "pars0lex.l"
{
			return(PARS_SYSDATE_TOKEN);
}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 435 "pars0lex.l"
{
			return(PARS_PRINTF_TOKEN);
}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 439 "pars0lex.l"
{
			return(PARS_ASSERT_TOKEN);
}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 443 "pars0lex.l"
{
			return(PARS_RND_TOKEN);
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 447 "pars0lex.l"
{
			return(PARS_RND_STR_TOKEN);
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 451 "pars0lex.l"
{
			return(PARS_ROW_PRINTF_TOKEN);
}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 455 "pars0lex.l"
{
			return(PARS_COMMIT_TOKEN);
}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 459 "pars0lex.l"
{
			return(PARS_ROLLBACK_TOKEN);
}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 463 "pars0lex.l"
{
			return(PARS_WORK_TOKEN);
}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 467 "pars0lex.l"
{
			yylval = sym_tab_add_id(pars_sym_tab_global,
							(byte*)yytext,
							ut_strlen(yytext));
			return(PARS_ID_TOKEN);
}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 474 "pars0lex.l"
{
			return(PARS_DDOT_TOKEN);
}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 478 "pars0lex.l"
{
			return(PARS_ASSIGN_TOKEN);
}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 482 "pars0lex.l"
{
			return(PARS_LE_TOKEN);
}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 486 "pars0lex.l"
{
			return(PARS_GE_TOKEN);
}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 490 "pars0lex.l"
{
			return(PARS_NE_TOKEN);
}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 494 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 499 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 504 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 509 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 514 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 519 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 524 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 529 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 534 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 539 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 544 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 549 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 554 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 559 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 564 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 569 "pars0lex.l"
BEGIN(comment); /* eat up comment */
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
#line 571 "pars0lex.l"

	YY_BREAK
case 105:
/* rule 105 can match eol */
YY_RULE_SETUP
#line 572 "pars0lex.l"

	YY_BREAK
case 106:
YY_RULE_SETUP
#line 573 "pars0lex.l"
BEGIN(INITIAL);
	YY_BREAK
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
#line 575 "pars0lex.l"
/* eat up whitespace */
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 578 "pars0lex.l"
{
			fprintf(stderr,"Unrecognized character: %02x\n",
				*yytext);

			ut_error;

			return(0);
}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 587 "pars0lex.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1799 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
case YY_STATE_EOF(quoted):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 370 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 370 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 369);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
				int offset = (int)(yy_c_buf_p - yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
    	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
    	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 587 "pars0lex.l"



